ClusterVector
=============

.. doxygenclass:: aare::ClusterVector
   :members:
   :undoc-members:
   :private-members:



.. doxygenclass:: aare::ClusterVector< Cluster< T, ClusterSizeX, ClusterSizeY, CoordType > > 
   :members:
   :undoc-members:
   :private-members:
   